Educational Resources
=====================

This is the curated list of resources for learning Dask:

*   `Tutorials`_
*   `Examples`_
*   `Presentations`_

.. _`Tutorials`: https://tutorial.dask.org/
.. _`Examples`: https://examples.dask.org/
.. _`Presentations`: https://docs.dask.org/en/latest/presentations.html